@@ -308,32 +308,58 @@ class Phonetic_Manipulation():
 		word = re.sub(u'\u0361', '&', word)
 
 		new_word = []
+		x = 0
+		y = 0
+		affricate = []
+		diphthong = []
+		skip = False
+		if '&' in word:
+			if re.search(f'{pm.vowels}&{pm.vowels}', word):
+				letter = re.search(f'{pm.vowels}&{pm.vowels}', word)[0]
+				for l in letter.split('&'):
+					i = pm.ipa_p.index(l)
+					diphthong.append(pm.ipa_x[i])
+				diphthong = ''.join(diphthong)
+				d_x = word.index(letter[-1])+1
+			if re.search(f'{pm.consonants}&{pm.consonants}', word):
+				letter = re.search(f'{pm.consonants}&{pm.consonants}', word)[0]
+				for l in letter.split('&'):
+					i = pm.ipa_p.index(l)
+					affricate.append(pm.ipa_x[i])
+				affricate = ''.join(affricate)
+				a_x = word.index(letter[-1])+1
 		for letter in word:
-			if '&' in letter:
-				if re.search(self.vowels, letter):
-					letter = letter.split('&')
-					diphthong = []
-					for l in letter:
-						i = self.ipa_p.index(l)
-						diphthong.append(self.ipa_x[i])
-					new_word.append('&'.join(diphthong))
-				else:
-					letter = letter.split('&')
-					affricate = []
-					for l in letter:
-						i = self.ipa_p.index(l)
-						affricate.append(self.ipa_x[i])
-					new_word.append(''.join(affricate))
-			if letter in self.dm_p:
-				i = self.dm_p.index(letter)
-				new_word.append(self.dm_x[i])
-				continue
-			if letter in self.ipa_p:
-				i = self.ipa_p.index(letter)
-				new_word.append(self.ipa_x[i])
+			if not skip:
+				if letter in pm.dm_p:
+					i = pm.dm_p.index(letter)
+					new_word.append(pm.dm_x[i])
+					continue
+				if letter in pm.ipa_p:
+					i = pm.ipa_p.index(letter)
+					new_word.append(pm.ipa_x[i])
+				elif affricate and diphthong:
+					if d_x < a_x:
+						skip = True
+						if diphthong not in new_word:
+							new_word[-1] = diphthong
+						else:
+							new_word[-1] = affricate
+					elif d_x > a_x:
+						skip = True
+						if affricate not in new_word:
+							new_word[-1] = affricate
+						else:
+							new_word[-1] = diphthong
+				elif affricate:
+					new_word[-1] = affricate
+					skip = True
+				elif diphthong:
+					new_word[-1] = diphthong
+					skip=True
 			else:
-				new_word.append(letter)
-	
+				skip = False
+				continue
+				
 		word = re.sub(' _', '_', ' '.join(new_word))
 
 		return word
